maxRetryCount property
Maximum number of retry attempts when an ad fails to load.
Uses exponential backoff starting from retryBaseDelayMs. Defaults to 3.
Implementation
final int maxRetryCount;
Maximum number of retry attempts when an ad fails to load.
Uses exponential backoff starting from retryBaseDelayMs. Defaults to 3.
final int maxRetryCount;