skipColdStartAppOpen property
Whether to skip app-open ads on cold start (first launch).
Defaults to true to avoid showing ads before the user
has seen any app content.
Implementation
final bool skipColdStartAppOpen;
Whether to skip app-open ads on cold start (first launch).
Defaults to true to avoid showing ads before the user
has seen any app content.
final bool skipColdStartAppOpen;