AdError class

Ad loading error information.

Constructors

AdError({required int code, required String message, String? domain})
Creates an ad error.
const

Properties

code int
The error code.
final
domain String?
The error domain (platform-specific).
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited