AdPaidValue class

Revenue data from a paid ad event.

Use this to track ad revenue in your analytics system.

Constructors

AdPaidValue({required int valueMicros, required String currencyCode, required String precision})
Creates a paid value entry.
const

Properties

currencyCode String
ISO 4217 currency code (e.g., "USD", "JPY").
final
hashCode int
The hash code for this object.
no setterinherited
precision String
The precision of the value (e.g., "ESTIMATED", "PRECISE").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueMicros int
The revenue value in micros (1/1,000,000 of the currency unit).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited