AdReward class

Reward earned from watching a rewarded ad.

Constructors

AdReward({required int amount, required String type})
Creates a reward.
const

Properties

amount int
The reward amount (e.g., number of coins).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The reward type (e.g., "coins", "gems").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited