ConsentStatus enum

UMP consent status.

Mirrors the consent statuses from the Google User Messaging Platform.

Inheritance
Available extensions

Values

unknown → const ConsentStatus

Consent status is unknown (not yet checked).

required → const ConsentStatus

Consent is required but has not been obtained.

notRequired → const ConsentStatus

Consent is not required in this region.

obtained → const ConsentStatus

Consent has been obtained.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConsentStatus>
A constant List of the values in this enum, in order of their declaration.