consent property
Access to the UMP consent manager.
Use this to check consent status or manually trigger the consent dialog from a settings screen.
Implementation
@override
ConsentManager get consent => _consent;
Access to the UMP consent manager.
Use this to check consent status or manually trigger the consent dialog from a settings screen.
@override
ConsentManager get consent => _consent;