recordImpression method
void
recordImpression()
Records that an ad was shown at the current time.
Implementation
void recordImpression() {
_lastShowTime = DateTime.now();
}
Records that an ad was shown at the current time.
void recordImpression() {
_lastShowTime = DateTime.now();
}